pub struct SpacecraftSequence {
pub seq: BTreeMap<Epoch, Phase>,
pub thruster_sets: IndexMap<String, Thruster>,
pub propagators: IndexMap<String, PropagatorConfig>,
/* private fields */
}Fields
seq: BTreeMap<Epoch, Phase>thruster_sets: IndexMap<String, Thruster>propagators: IndexMap<String, PropagatorConfig>Implementations
Sourceimpl SpacecraftSequence
impl SpacecraftSequence
pub fn validate(&self) -> Result<(), String>
Sourcepub fn setup(&mut self, almanac: Arc<Almanac>) -> Result<(), String>
pub fn setup(&mut self, almanac: Arc<Almanac>) -> Result<(), String>
Set up the propagators that are used in the timeline
Sourcepub fn propagate(
&self,
state: Spacecraft,
until_phase: Option<String>,
almanac: Arc<Almanac>,
) -> Result<Vec<Trajectory>, NyxError>
pub fn propagate( &self, state: Spacecraft, until_phase: Option<String>, almanac: Arc<Almanac>, ) -> Result<Vec<Trajectory>, NyxError>
Propagate this plan starting the relevant phase for the probided state, and propagating until the end of the plan or until the provided phase name. Returns the trajectory for each phase, allowing for each phase to be in its own central body.